@@ -108,8 +108,6 @@ main(int argc, char **argv)
 	int c;			/* option */
 	int index;
 	int maxindex;
-	/* fix gcc warning bug */
-	int unusedint = 0;
 	char *cp;
 	char *endcp;
 	char *bp;
@@ -289,9 +287,7 @@ main(int argc, char **argv)
 						    exit(6);
 						}
 						calc_debug = cp;
-						/* fix gcc warning bug */
-						unusedint =
-						    strtol(cp, &endcp, 10);
+						(void) strtol(cp, &endcp, 10);
 						cp = endcp;
 						if (*cp != '\0' &&
 						    *cp != ' ' && *cp != ':') {
@@ -323,9 +319,7 @@ main(int argc, char **argv)
 						    exit(9);
 						}
 						resource_debug = cp;
-						/* fix gcc warning bug */
-						unusedint =
-						    strtol(cp, &endcp, 10);
+						(void) strtol(cp, &endcp, 10);
 						cp = endcp;
 						if (*cp != '\0' &&
 						    *cp != ' ' && *cp != ':') {
@@ -355,8 +349,7 @@ main(int argc, char **argv)
 					    exit(12);
 					}
 					user_debug = cp;
-					/* unusedint avoids gcc warning bug */
-					unusedint = strtol(cp, &endcp, 10);
+					(void) strtol(cp, &endcp, 10);
 					cp = endcp;
 					if (*cp != '\0' && *cp != ' ') {
 						fprintf(stderr, "Bad syntax in"
@@ -765,8 +758,6 @@ main(int argc, char **argv)
 	/*
 	 * All done! - Jessica Noll, Age 2
 	 */
-	/* fix gcc warning bug */
-	unusedint++;
 	libcalc_call_me_last();
 	return (run_state == RUN_EXIT_WITH_ERROR ||
 		run_state == RUN_ZERO) ? 1 : 0;
