@@ -1191,12 +1191,18 @@ comprint(COMPLEX *c)
 	qtmp = c->imag[0];
 	if (qiszero(&qtmp))
 		return;
+	if (conf->complex_space) {
+	    math_chr(' ');
+	}
 	if (!qiszero(c->real) && !qisneg(&qtmp))
 		math_chr('+');
 	if (qisneg(&qtmp)) {
 		math_chr('-');
 		qtmp.num.sign = 0;
 	}
+	if (conf->complex_space) {
+	    math_chr(' ');
+	}
 	qprintnum(&qtmp, MODE_DEFAULT, conf->outdigits);
 	math_chr('i');
 }
@@ -1223,7 +1229,13 @@ cprintfr(COMPLEX *c)
 	zprintval(i->num, 0L, 0L);
 	math_chr('i');
 	if (qisfrac(i)) {
+		if (conf->fraction_space) {
+		    math_chr(' ');
+		}
 		math_chr('/');
+		if (conf->fraction_space) {
+		    math_chr(' ');
+		}
 		zprintval(i->den, 0L, 0L);
 	}
 }
