@@ -57,7 +57,7 @@ c_argv(char *UNUSED(name), int count, VALUE **vals)
 {
 	VALUE result;		/* what we will return */
 	ZVALUE zfilelen;	/* length of a file as a ZVALUE */
-	NUMBER *filelen;	/* pointer to length of a file as a NUMER */
+	NUMBER *filelen;	/* pointer to length of a file as a NUMBER */
 	char *type;		/* the name of the arg type */
 	int i;
 
@@ -103,12 +103,12 @@ c_argv(char *UNUSED(name), int count, VALUE **vals)
 			type = "assoc";
 			break;
 		case V_OBJ:	/* address of object structure */
-			type = "ocject";
+			type = "object";
 			break;
 		case V_FILE:	/* opened file id */
 			type = "file";
 			break;
-		case V_RAND:	/* address of additive 55 random state */
+		case V_RAND:	/* subtractive 100 random state */
 			type = "rand_state";
 			break;
 		case V_RANDOM:	/* address of Blum random state */
