@@ -39,7 +39,7 @@
 #include "calc.h"
 #include "alloc.h"
 #include "longbits.h"
-#include "have_fpos.h"
+#include "have_fgetsetpos.h"
 #include "have_fpos_pos.h"
 #include "fposval.h"
 #include "file.h"
@@ -1459,7 +1459,7 @@ z2filepos(ZVALUE zpos)
 	if (zpos.len >= FILEPOS_BITS/BASEB) {
 		/* copy the lower FILEPOS_BITS of the ZVALUE */
 		memset(&tmp, 0, sizeof(tmp)); /* FILEPOS could be non-scalar */
-		memcpy(&tmp, zpos.v, MIN(sizeof(tmp), FILEPOS_LEN);
+		memcpy(&tmp, zpos.v, MIN(sizeof(tmp), FILEPOS_LEN));
 	} else {
 		/* copy what bits we can into the temp value */
 		memset(&tmp, 0, sizeof(tmp)); /* FILEPOS could be non-scalar */
@@ -2022,7 +2022,7 @@ showfiles(void)
 			math_chr('\n');
 			continue;
 		}
-		printf(" size = %lld\n", (long long int)sizes[i]);
+		printf(" size = %ld\n", (long int)sizes[i]);
 		for (j = i + 1; j < idnum; j++) {
 			if (listed[j] || sizes[j] == -1)
 				continue;
