@@ -40,7 +40,7 @@
 #include <unistd.h>
 #endif
 
-#if defined(_WIN32)
+#if defined(_WIN32) || defined(_WIN64)
 # define popen _popen
 # define pclose _pclose
 #endif
@@ -87,6 +87,7 @@ STATIC struct help_alias {
 	{"dm2d", "dms2d"},
 	{"gm2g", "gms2g"},
 	{"hm2d", "hms2d"},
+	{"release", "releases"},
 	{NULL, NULL}
 };
 
