@@ -1,7 +1,7 @@
 /*
  * longbits - Determine the number if bits in a char, short, int or long
  *
- * Copyright (C) 1999-2007,2014  Landon Curt Noll
+ * Copyright (C) 1999-2007,2014,2021  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -56,7 +56,7 @@
  *	SB32	signed 32 bit value
  *
  *	HAVE_B64
- *		defined ==> ok to use USB64 (unsigned 64 bit value)
+ *		defined ==> OK to use USB64 (unsigned 64 bit value)
  *				  and SB64 (signed 64 bit value)
  *		undefined ==> do not use USB64 nor SB64
  *
@@ -92,6 +92,12 @@
 # include <stdlib.h>
 #endif
 
+#include "charbit.h"
+
+
+#include "banned.h"	/* include after system header <> includes */
+
+
 char *program;		/* our name */
 
 int
@@ -114,7 +120,7 @@ main(int argc, char **argv)
 		/* ignore empty or leading space args */
 		if (argv[1][0] == '\0' ||
 		    (isascii((int)argv[1][0]) && isspace((int)argv[1][0]))) {
-			long_bits = sizeof(long)*8;
+			long_bits = sizeof(long)*CALC_CHARBIT;
 		/* process the forced size arg */
 		} else {
 			forced_size = 1;
