@@ -1,7 +1,7 @@
 /*
  * sample_rand - test the libcalc random number generator
  *
- * Copyright (C) 1999-2007,2021  Landon Curt Noll
+ * Copyright (C) 1999-2007,2021,2022  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -41,6 +41,7 @@
 #include "lib_util.h"
 
 
+#include "attribute.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -96,7 +97,7 @@ main(int argc, char **argv)
 	prev_state = zsrandom2(seed, _ten_);
 	if (prev_state == NULL) {
 		math_error("previous random state is NULL");
-		/*NOTREACHED*/
+		not_reached();
 	}
 
 	/*
